# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/instance_template/instance_template_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.instance_template import instance_template_pb2 as qwak_dot_instance__template_dot_instance__template__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6qwak/instance_template/instance_template_service.proto\x12!qwak.management.instance_template\x1a.qwak/instance_template/instance_template.proto\"s\n\x1cListInstanceTemplatesRequest\x12S\n\x18optional_instance_filter\x18\x01 \x01(\x0b\x32\x31.qwak.management.instance_template.InstanceFilter\"x\n\x1dListInstanceTemplatesResponse\x12W\n\x16instance_template_list\x18\x01 \x03(\x0b\x32\x37.qwak.management.instance_template.InstanceTemplateSpec\"(\n\x1aGetInstanceTemplateRequest\x12\n\n\x02id\x18\x01 \x01(\t\"q\n\x1bGetInstanceTemplateResponse\x12R\n\x11instance_template\x18\x01 \x01(\x0b\x32\x37.qwak.management.instance_template.InstanceTemplateSpec2\xd7\x02\n!InstanceTemplateManagementService\x12\x9a\x01\n\x15ListInstanceTemplates\x12?.qwak.management.instance_template.ListInstanceTemplatesRequest\x1a@.qwak.management.instance_template.ListInstanceTemplatesResponse\x12\x94\x01\n\x13GetInstanceTemplate\x12=.qwak.management.instance_template.GetInstanceTemplateRequest\x1a>.qwak.management.instance_template.GetInstanceTemplateResponseB0\n,com.qwak.ai.management.instance_template.apiP\x01\x62\x06proto3')



_LISTINSTANCETEMPLATESREQUEST = DESCRIPTOR.message_types_by_name['ListInstanceTemplatesRequest']
_LISTINSTANCETEMPLATESRESPONSE = DESCRIPTOR.message_types_by_name['ListInstanceTemplatesResponse']
_GETINSTANCETEMPLATEREQUEST = DESCRIPTOR.message_types_by_name['GetInstanceTemplateRequest']
_GETINSTANCETEMPLATERESPONSE = DESCRIPTOR.message_types_by_name['GetInstanceTemplateResponse']
ListInstanceTemplatesRequest = _reflection.GeneratedProtocolMessageType('ListInstanceTemplatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCETEMPLATESREQUEST,
  '__module__' : 'qwak.instance_template.instance_template_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.management.instance_template.ListInstanceTemplatesRequest)
  })
_sym_db.RegisterMessage(ListInstanceTemplatesRequest)

ListInstanceTemplatesResponse = _reflection.GeneratedProtocolMessageType('ListInstanceTemplatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCETEMPLATESRESPONSE,
  '__module__' : 'qwak.instance_template.instance_template_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.management.instance_template.ListInstanceTemplatesResponse)
  })
_sym_db.RegisterMessage(ListInstanceTemplatesResponse)

GetInstanceTemplateRequest = _reflection.GeneratedProtocolMessageType('GetInstanceTemplateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTANCETEMPLATEREQUEST,
  '__module__' : 'qwak.instance_template.instance_template_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.management.instance_template.GetInstanceTemplateRequest)
  })
_sym_db.RegisterMessage(GetInstanceTemplateRequest)

GetInstanceTemplateResponse = _reflection.GeneratedProtocolMessageType('GetInstanceTemplateResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTANCETEMPLATERESPONSE,
  '__module__' : 'qwak.instance_template.instance_template_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.management.instance_template.GetInstanceTemplateResponse)
  })
_sym_db.RegisterMessage(GetInstanceTemplateResponse)

_INSTANCETEMPLATEMANAGEMENTSERVICE = DESCRIPTOR.services_by_name['InstanceTemplateManagementService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n,com.qwak.ai.management.instance_template.apiP\001'
  _LISTINSTANCETEMPLATESREQUEST._serialized_start=141
  _LISTINSTANCETEMPLATESREQUEST._serialized_end=256
  _LISTINSTANCETEMPLATESRESPONSE._serialized_start=258
  _LISTINSTANCETEMPLATESRESPONSE._serialized_end=378
  _GETINSTANCETEMPLATEREQUEST._serialized_start=380
  _GETINSTANCETEMPLATEREQUEST._serialized_end=420
  _GETINSTANCETEMPLATERESPONSE._serialized_start=422
  _GETINSTANCETEMPLATERESPONSE._serialized_end=535
  _INSTANCETEMPLATEMANAGEMENTSERVICE._serialized_start=538
  _INSTANCETEMPLATEMANAGEMENTSERVICE._serialized_end=881
# @@protoc_insertion_point(module_scope)
