"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.feature_store.features.deployment_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PushEnvironmentDeploymentStateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    DEPLOYMENT_STATE_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    @property
    def deployment_state(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.feature_store.features.deployment_pb2.DeploymentState]: ...
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
        deployment_state: collections.abc.Iterable[qwak.feature_store.features.deployment_pb2.DeploymentState] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_state", b"deployment_state", "environment_id", b"environment_id"]) -> None: ...

global___PushEnvironmentDeploymentStateRequest = PushEnvironmentDeploymentStateRequest

class PushEnvironmentDeploymentStateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PushEnvironmentDeploymentStateResponse = PushEnvironmentDeploymentStateResponse
