# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/workspace/workspace_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.workspace import workspace_pb2 as qwak_dot_workspace_dot_workspace__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&qwak/workspace/workspace_service.proto\x12\x19qwak.workspace.management\x1a\x1eqwak/workspace/workspace.proto\"Z\n\x16\x43reateWorkspaceRequest\x12@\n\x0eworkspace_spec\x18\x01 \x01(\x0b\x32(.qwak.workspace.management.WorkspaceSpec\"/\n\x17\x43reateWorkspaceResponse\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\"p\n\x16UpdateWorkspaceRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12@\n\x0eworkspace_spec\x18\x02 \x01(\x0b\x32(.qwak.workspace.management.WorkspaceSpec\".\n\x16\x44\x65ployWorkspaceRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\"\x19\n\x17\x44\x65ployWorkspaceResponse\"0\n\x18UndeployWorkspaceRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\"\x1b\n\x19UndeployWorkspaceResponse\"\x19\n\x17UpdateWorkspaceResponse\"\x17\n\x15ListWorkspacesRequest\"R\n\x16ListWorkspacesResponse\x12\x38\n\nworkspaces\x18\x01 \x03(\x0b\x32$.qwak.workspace.management.Workspace\"/\n\x17GetWorkspaceByIdRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\"S\n\x18GetWorkspaceByIdResponse\x12\x37\n\tworkspace\x18\x01 \x01(\x0b\x32$.qwak.workspace.management.Workspace\".\n\x16\x44\x65leteWorkspaceRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\"\x19\n\x17\x44\x65leteWorkspaceResponse\"\x9a\x01\n$UpdateWorkspaceStatusFromEdgeRequest\x12r\n)update_workspace_status_from_edge_details\x18\x01 \x01(\x0b\x32?.qwak.workspace.management.UpdateWorkspaceStatusFromEdgeDetails\"\'\n%UpdateWorkspaceStatusFromEdgeResponse\"A\n\x1bRegisterWorkspaceTagRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x0c\n\x04tags\x18\x02 \x03(\t\"\x1e\n\x1cRegisterWorkspaceTagResponse\"\x1c\n\x1aListWorkspaceImagesRequest\"b\n\x1bListWorkspaceImagesResponse\x12\x43\n\x10workspace_images\x18\x01 \x03(\x0b\x32).qwak.workspace.management.WorkspaceImage\"\x18\n\x16\x43ountWorkspacesRequest\"(\n\x17\x43ountWorkspacesResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\"\"\n GetDefaultWorkspaceValuesRequest\"z\n!GetDefaultWorkspaceValuesResponse\x12U\n\x19\x64\x65\x66\x61ult_workspace_details\x18\x01 \x01(\x0b\x32\x32.qwak.workspace.management.DefaultWorkspaceDetails\"B\n\x18MarkBuildAsCopiedRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\"\x1b\n\x19MarkBuildAsCopiedResponse\":\n\x10\x43opyBuildRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\"\x13\n\x11\x43opyBuildResponse2\xaa\x0e\n\x1aWorkspaceManagementService\x12x\n\x0f\x43reateWorkspace\x12\x31.qwak.workspace.management.CreateWorkspaceRequest\x1a\x32.qwak.workspace.management.CreateWorkspaceResponse\x12x\n\x0fUpdateWorkspace\x12\x31.qwak.workspace.management.UpdateWorkspaceRequest\x1a\x32.qwak.workspace.management.UpdateWorkspaceResponse\x12x\n\x0f\x44\x65ployWorkspace\x12\x31.qwak.workspace.management.DeployWorkspaceRequest\x1a\x32.qwak.workspace.management.DeployWorkspaceResponse\x12~\n\x11UndeployWorkspace\x12\x33.qwak.workspace.management.UndeployWorkspaceRequest\x1a\x34.qwak.workspace.management.UndeployWorkspaceResponse\x12u\n\x0eListWorkspaces\x12\x30.qwak.workspace.management.ListWorkspacesRequest\x1a\x31.qwak.workspace.management.ListWorkspacesResponse\x12{\n\x10GetWorkspaceById\x12\x32.qwak.workspace.management.GetWorkspaceByIdRequest\x1a\x33.qwak.workspace.management.GetWorkspaceByIdResponse\x12x\n\x0f\x44\x65leteWorkspace\x12\x31.qwak.workspace.management.DeleteWorkspaceRequest\x1a\x32.qwak.workspace.management.DeleteWorkspaceResponse\x12\xa2\x01\n\x1dUpdateWorkspaceStatusFromEdge\x12?.qwak.workspace.management.UpdateWorkspaceStatusFromEdgeRequest\x1a@.qwak.workspace.management.UpdateWorkspaceStatusFromEdgeResponse\x12\x84\x01\n\x13ListWorkspaceImages\x12\x35.qwak.workspace.management.ListWorkspaceImagesRequest\x1a\x36.qwak.workspace.management.ListWorkspaceImagesResponse\x12\x88\x01\n\x15RegisterWorkspaceTags\x12\x36.qwak.workspace.management.RegisterWorkspaceTagRequest\x1a\x37.qwak.workspace.management.RegisterWorkspaceTagResponse\x12x\n\x0f\x43ountWorkspaces\x12\x31.qwak.workspace.management.CountWorkspacesRequest\x1a\x32.qwak.workspace.management.CountWorkspacesResponse\x12\x96\x01\n\x19GetDefaultWorkspaceValues\x12;.qwak.workspace.management.GetDefaultWorkspaceValuesRequest\x1a<.qwak.workspace.management.GetDefaultWorkspaceValuesResponse\x12~\n\x11MarkBuildAsCopied\x12\x33.qwak.workspace.management.MarkBuildAsCopiedRequest\x1a\x34.qwak.workspace.management.MarkBuildAsCopiedResponse\x12\x66\n\tCopyBuild\x12+.qwak.workspace.management.CopyBuildRequest\x1a,.qwak.workspace.management.CopyBuildResponseBB\n$com.qwak.ai.management.workspace.apiP\x01Z\x18qwak/workspace;workspaceb\x06proto3')



_CREATEWORKSPACEREQUEST = DESCRIPTOR.message_types_by_name['CreateWorkspaceRequest']
_CREATEWORKSPACERESPONSE = DESCRIPTOR.message_types_by_name['CreateWorkspaceResponse']
_UPDATEWORKSPACEREQUEST = DESCRIPTOR.message_types_by_name['UpdateWorkspaceRequest']
_DEPLOYWORKSPACEREQUEST = DESCRIPTOR.message_types_by_name['DeployWorkspaceRequest']
_DEPLOYWORKSPACERESPONSE = DESCRIPTOR.message_types_by_name['DeployWorkspaceResponse']
_UNDEPLOYWORKSPACEREQUEST = DESCRIPTOR.message_types_by_name['UndeployWorkspaceRequest']
_UNDEPLOYWORKSPACERESPONSE = DESCRIPTOR.message_types_by_name['UndeployWorkspaceResponse']
_UPDATEWORKSPACERESPONSE = DESCRIPTOR.message_types_by_name['UpdateWorkspaceResponse']
_LISTWORKSPACESREQUEST = DESCRIPTOR.message_types_by_name['ListWorkspacesRequest']
_LISTWORKSPACESRESPONSE = DESCRIPTOR.message_types_by_name['ListWorkspacesResponse']
_GETWORKSPACEBYIDREQUEST = DESCRIPTOR.message_types_by_name['GetWorkspaceByIdRequest']
_GETWORKSPACEBYIDRESPONSE = DESCRIPTOR.message_types_by_name['GetWorkspaceByIdResponse']
_DELETEWORKSPACEREQUEST = DESCRIPTOR.message_types_by_name['DeleteWorkspaceRequest']
_DELETEWORKSPACERESPONSE = DESCRIPTOR.message_types_by_name['DeleteWorkspaceResponse']
_UPDATEWORKSPACESTATUSFROMEDGEREQUEST = DESCRIPTOR.message_types_by_name['UpdateWorkspaceStatusFromEdgeRequest']
_UPDATEWORKSPACESTATUSFROMEDGERESPONSE = DESCRIPTOR.message_types_by_name['UpdateWorkspaceStatusFromEdgeResponse']
_REGISTERWORKSPACETAGREQUEST = DESCRIPTOR.message_types_by_name['RegisterWorkspaceTagRequest']
_REGISTERWORKSPACETAGRESPONSE = DESCRIPTOR.message_types_by_name['RegisterWorkspaceTagResponse']
_LISTWORKSPACEIMAGESREQUEST = DESCRIPTOR.message_types_by_name['ListWorkspaceImagesRequest']
_LISTWORKSPACEIMAGESRESPONSE = DESCRIPTOR.message_types_by_name['ListWorkspaceImagesResponse']
_COUNTWORKSPACESREQUEST = DESCRIPTOR.message_types_by_name['CountWorkspacesRequest']
_COUNTWORKSPACESRESPONSE = DESCRIPTOR.message_types_by_name['CountWorkspacesResponse']
_GETDEFAULTWORKSPACEVALUESREQUEST = DESCRIPTOR.message_types_by_name['GetDefaultWorkspaceValuesRequest']
_GETDEFAULTWORKSPACEVALUESRESPONSE = DESCRIPTOR.message_types_by_name['GetDefaultWorkspaceValuesResponse']
_MARKBUILDASCOPIEDREQUEST = DESCRIPTOR.message_types_by_name['MarkBuildAsCopiedRequest']
_MARKBUILDASCOPIEDRESPONSE = DESCRIPTOR.message_types_by_name['MarkBuildAsCopiedResponse']
_COPYBUILDREQUEST = DESCRIPTOR.message_types_by_name['CopyBuildRequest']
_COPYBUILDRESPONSE = DESCRIPTOR.message_types_by_name['CopyBuildResponse']
CreateWorkspaceRequest = _reflection.GeneratedProtocolMessageType('CreateWorkspaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWORKSPACEREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.CreateWorkspaceRequest)
  })
_sym_db.RegisterMessage(CreateWorkspaceRequest)

CreateWorkspaceResponse = _reflection.GeneratedProtocolMessageType('CreateWorkspaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWORKSPACERESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.CreateWorkspaceResponse)
  })
_sym_db.RegisterMessage(CreateWorkspaceResponse)

UpdateWorkspaceRequest = _reflection.GeneratedProtocolMessageType('UpdateWorkspaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWORKSPACEREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.UpdateWorkspaceRequest)
  })
_sym_db.RegisterMessage(UpdateWorkspaceRequest)

DeployWorkspaceRequest = _reflection.GeneratedProtocolMessageType('DeployWorkspaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYWORKSPACEREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.DeployWorkspaceRequest)
  })
_sym_db.RegisterMessage(DeployWorkspaceRequest)

DeployWorkspaceResponse = _reflection.GeneratedProtocolMessageType('DeployWorkspaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYWORKSPACERESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.DeployWorkspaceResponse)
  })
_sym_db.RegisterMessage(DeployWorkspaceResponse)

UndeployWorkspaceRequest = _reflection.GeneratedProtocolMessageType('UndeployWorkspaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UNDEPLOYWORKSPACEREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.UndeployWorkspaceRequest)
  })
_sym_db.RegisterMessage(UndeployWorkspaceRequest)

UndeployWorkspaceResponse = _reflection.GeneratedProtocolMessageType('UndeployWorkspaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _UNDEPLOYWORKSPACERESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.UndeployWorkspaceResponse)
  })
_sym_db.RegisterMessage(UndeployWorkspaceResponse)

UpdateWorkspaceResponse = _reflection.GeneratedProtocolMessageType('UpdateWorkspaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWORKSPACERESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.UpdateWorkspaceResponse)
  })
_sym_db.RegisterMessage(UpdateWorkspaceResponse)

ListWorkspacesRequest = _reflection.GeneratedProtocolMessageType('ListWorkspacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTWORKSPACESREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.ListWorkspacesRequest)
  })
_sym_db.RegisterMessage(ListWorkspacesRequest)

ListWorkspacesResponse = _reflection.GeneratedProtocolMessageType('ListWorkspacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTWORKSPACESRESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.ListWorkspacesResponse)
  })
_sym_db.RegisterMessage(ListWorkspacesResponse)

GetWorkspaceByIdRequest = _reflection.GeneratedProtocolMessageType('GetWorkspaceByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETWORKSPACEBYIDREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.GetWorkspaceByIdRequest)
  })
_sym_db.RegisterMessage(GetWorkspaceByIdRequest)

GetWorkspaceByIdResponse = _reflection.GeneratedProtocolMessageType('GetWorkspaceByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETWORKSPACEBYIDRESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.GetWorkspaceByIdResponse)
  })
_sym_db.RegisterMessage(GetWorkspaceByIdResponse)

DeleteWorkspaceRequest = _reflection.GeneratedProtocolMessageType('DeleteWorkspaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEWORKSPACEREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.DeleteWorkspaceRequest)
  })
_sym_db.RegisterMessage(DeleteWorkspaceRequest)

DeleteWorkspaceResponse = _reflection.GeneratedProtocolMessageType('DeleteWorkspaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEWORKSPACERESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.DeleteWorkspaceResponse)
  })
_sym_db.RegisterMessage(DeleteWorkspaceResponse)

UpdateWorkspaceStatusFromEdgeRequest = _reflection.GeneratedProtocolMessageType('UpdateWorkspaceStatusFromEdgeRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWORKSPACESTATUSFROMEDGEREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.UpdateWorkspaceStatusFromEdgeRequest)
  })
_sym_db.RegisterMessage(UpdateWorkspaceStatusFromEdgeRequest)

UpdateWorkspaceStatusFromEdgeResponse = _reflection.GeneratedProtocolMessageType('UpdateWorkspaceStatusFromEdgeResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWORKSPACESTATUSFROMEDGERESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.UpdateWorkspaceStatusFromEdgeResponse)
  })
_sym_db.RegisterMessage(UpdateWorkspaceStatusFromEdgeResponse)

RegisterWorkspaceTagRequest = _reflection.GeneratedProtocolMessageType('RegisterWorkspaceTagRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERWORKSPACETAGREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.RegisterWorkspaceTagRequest)
  })
_sym_db.RegisterMessage(RegisterWorkspaceTagRequest)

RegisterWorkspaceTagResponse = _reflection.GeneratedProtocolMessageType('RegisterWorkspaceTagResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERWORKSPACETAGRESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.RegisterWorkspaceTagResponse)
  })
_sym_db.RegisterMessage(RegisterWorkspaceTagResponse)

ListWorkspaceImagesRequest = _reflection.GeneratedProtocolMessageType('ListWorkspaceImagesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTWORKSPACEIMAGESREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.ListWorkspaceImagesRequest)
  })
_sym_db.RegisterMessage(ListWorkspaceImagesRequest)

ListWorkspaceImagesResponse = _reflection.GeneratedProtocolMessageType('ListWorkspaceImagesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTWORKSPACEIMAGESRESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.ListWorkspaceImagesResponse)
  })
_sym_db.RegisterMessage(ListWorkspaceImagesResponse)

CountWorkspacesRequest = _reflection.GeneratedProtocolMessageType('CountWorkspacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _COUNTWORKSPACESREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.CountWorkspacesRequest)
  })
_sym_db.RegisterMessage(CountWorkspacesRequest)

CountWorkspacesResponse = _reflection.GeneratedProtocolMessageType('CountWorkspacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _COUNTWORKSPACESRESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.CountWorkspacesResponse)
  })
_sym_db.RegisterMessage(CountWorkspacesResponse)

GetDefaultWorkspaceValuesRequest = _reflection.GeneratedProtocolMessageType('GetDefaultWorkspaceValuesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDEFAULTWORKSPACEVALUESREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.GetDefaultWorkspaceValuesRequest)
  })
_sym_db.RegisterMessage(GetDefaultWorkspaceValuesRequest)

GetDefaultWorkspaceValuesResponse = _reflection.GeneratedProtocolMessageType('GetDefaultWorkspaceValuesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDEFAULTWORKSPACEVALUESRESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.GetDefaultWorkspaceValuesResponse)
  })
_sym_db.RegisterMessage(GetDefaultWorkspaceValuesResponse)

MarkBuildAsCopiedRequest = _reflection.GeneratedProtocolMessageType('MarkBuildAsCopiedRequest', (_message.Message,), {
  'DESCRIPTOR' : _MARKBUILDASCOPIEDREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.MarkBuildAsCopiedRequest)
  })
_sym_db.RegisterMessage(MarkBuildAsCopiedRequest)

MarkBuildAsCopiedResponse = _reflection.GeneratedProtocolMessageType('MarkBuildAsCopiedResponse', (_message.Message,), {
  'DESCRIPTOR' : _MARKBUILDASCOPIEDRESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.MarkBuildAsCopiedResponse)
  })
_sym_db.RegisterMessage(MarkBuildAsCopiedResponse)

CopyBuildRequest = _reflection.GeneratedProtocolMessageType('CopyBuildRequest', (_message.Message,), {
  'DESCRIPTOR' : _COPYBUILDREQUEST,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.CopyBuildRequest)
  })
_sym_db.RegisterMessage(CopyBuildRequest)

CopyBuildResponse = _reflection.GeneratedProtocolMessageType('CopyBuildResponse', (_message.Message,), {
  'DESCRIPTOR' : _COPYBUILDRESPONSE,
  '__module__' : 'qwak.workspace.workspace_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.workspace.management.CopyBuildResponse)
  })
_sym_db.RegisterMessage(CopyBuildResponse)

_WORKSPACEMANAGEMENTSERVICE = DESCRIPTOR.services_by_name['WorkspaceManagementService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$com.qwak.ai.management.workspace.apiP\001Z\030qwak/workspace;workspace'
  _CREATEWORKSPACEREQUEST._serialized_start=101
  _CREATEWORKSPACEREQUEST._serialized_end=191
  _CREATEWORKSPACERESPONSE._serialized_start=193
  _CREATEWORKSPACERESPONSE._serialized_end=240
  _UPDATEWORKSPACEREQUEST._serialized_start=242
  _UPDATEWORKSPACEREQUEST._serialized_end=354
  _DEPLOYWORKSPACEREQUEST._serialized_start=356
  _DEPLOYWORKSPACEREQUEST._serialized_end=402
  _DEPLOYWORKSPACERESPONSE._serialized_start=404
  _DEPLOYWORKSPACERESPONSE._serialized_end=429
  _UNDEPLOYWORKSPACEREQUEST._serialized_start=431
  _UNDEPLOYWORKSPACEREQUEST._serialized_end=479
  _UNDEPLOYWORKSPACERESPONSE._serialized_start=481
  _UNDEPLOYWORKSPACERESPONSE._serialized_end=508
  _UPDATEWORKSPACERESPONSE._serialized_start=510
  _UPDATEWORKSPACERESPONSE._serialized_end=535
  _LISTWORKSPACESREQUEST._serialized_start=537
  _LISTWORKSPACESREQUEST._serialized_end=560
  _LISTWORKSPACESRESPONSE._serialized_start=562
  _LISTWORKSPACESRESPONSE._serialized_end=644
  _GETWORKSPACEBYIDREQUEST._serialized_start=646
  _GETWORKSPACEBYIDREQUEST._serialized_end=693
  _GETWORKSPACEBYIDRESPONSE._serialized_start=695
  _GETWORKSPACEBYIDRESPONSE._serialized_end=778
  _DELETEWORKSPACEREQUEST._serialized_start=780
  _DELETEWORKSPACEREQUEST._serialized_end=826
  _DELETEWORKSPACERESPONSE._serialized_start=828
  _DELETEWORKSPACERESPONSE._serialized_end=853
  _UPDATEWORKSPACESTATUSFROMEDGEREQUEST._serialized_start=856
  _UPDATEWORKSPACESTATUSFROMEDGEREQUEST._serialized_end=1010
  _UPDATEWORKSPACESTATUSFROMEDGERESPONSE._serialized_start=1012
  _UPDATEWORKSPACESTATUSFROMEDGERESPONSE._serialized_end=1051
  _REGISTERWORKSPACETAGREQUEST._serialized_start=1053
  _REGISTERWORKSPACETAGREQUEST._serialized_end=1118
  _REGISTERWORKSPACETAGRESPONSE._serialized_start=1120
  _REGISTERWORKSPACETAGRESPONSE._serialized_end=1150
  _LISTWORKSPACEIMAGESREQUEST._serialized_start=1152
  _LISTWORKSPACEIMAGESREQUEST._serialized_end=1180
  _LISTWORKSPACEIMAGESRESPONSE._serialized_start=1182
  _LISTWORKSPACEIMAGESRESPONSE._serialized_end=1280
  _COUNTWORKSPACESREQUEST._serialized_start=1282
  _COUNTWORKSPACESREQUEST._serialized_end=1306
  _COUNTWORKSPACESRESPONSE._serialized_start=1308
  _COUNTWORKSPACESRESPONSE._serialized_end=1348
  _GETDEFAULTWORKSPACEVALUESREQUEST._serialized_start=1350
  _GETDEFAULTWORKSPACEVALUESREQUEST._serialized_end=1384
  _GETDEFAULTWORKSPACEVALUESRESPONSE._serialized_start=1386
  _GETDEFAULTWORKSPACEVALUESRESPONSE._serialized_end=1508
  _MARKBUILDASCOPIEDREQUEST._serialized_start=1510
  _MARKBUILDASCOPIEDREQUEST._serialized_end=1576
  _MARKBUILDASCOPIEDRESPONSE._serialized_start=1578
  _MARKBUILDASCOPIEDRESPONSE._serialized_end=1605
  _COPYBUILDREQUEST._serialized_start=1607
  _COPYBUILDREQUEST._serialized_end=1665
  _COPYBUILDRESPONSE._serialized_start=1667
  _COPYBUILDRESPONSE._serialized_end=1686
  _WORKSPACEMANAGEMENTSERVICE._serialized_start=1689
  _WORKSPACEMANAGEMENTSERVICE._serialized_end=3523
# @@protoc_insertion_point(module_scope)
