"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.integration.integration_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CreateIntegrationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTEGRATION_SPEC_FIELD_NUMBER: builtins.int
    @property
    def integration_spec(self) -> qwak.integration.integration_pb2.IntegrationSpec:
        """The integration spec to add"""
    def __init__(
        self,
        *,
        integration_spec: qwak.integration.integration_pb2.IntegrationSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["integration_spec", b"integration_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["integration_spec", b"integration_spec"]) -> None: ...

global___CreateIntegrationRequest = CreateIntegrationRequest

class CreateIntegrationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTEGRATION_ID_FIELD_NUMBER: builtins.int
    IS_SUCCESSFUL_FIELD_NUMBER: builtins.int
    ERROR_MESSAGE_FIELD_NUMBER: builtins.int
    integration_id: builtins.str
    """The id of the created integration"""
    is_successful: builtins.bool
    """Is The creation successful"""
    error_message: builtins.str
    """The reason the integration failed"""
    def __init__(
        self,
        *,
        integration_id: builtins.str = ...,
        is_successful: builtins.bool = ...,
        error_message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["error_message", b"error_message", "integration_id", b"integration_id", "is_successful", b"is_successful"]) -> None: ...

global___CreateIntegrationResponse = CreateIntegrationResponse

class GetIntegrationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTEGRATION_ID_FIELD_NUMBER: builtins.int
    integration_id: builtins.str
    """Integration Id to get"""
    def __init__(
        self,
        *,
        integration_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["integration_id", b"integration_id"]) -> None: ...

global___GetIntegrationRequest = GetIntegrationRequest

class GetIntegrationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTEGRATION_FIELD_NUMBER: builtins.int
    @property
    def integration(self) -> qwak.integration.integration_pb2.Integration:
        """integration"""
    def __init__(
        self,
        *,
        integration: qwak.integration.integration_pb2.Integration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["integration", b"integration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["integration", b"integration"]) -> None: ...

global___GetIntegrationResponse = GetIntegrationResponse

class ListIntegrationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListIntegrationRequest = ListIntegrationRequest

class ListIntegrationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTEGRATIONS_FIELD_NUMBER: builtins.int
    @property
    def integrations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.integration.integration_pb2.Integration]:
        """list of integration"""
    def __init__(
        self,
        *,
        integrations: collections.abc.Iterable[qwak.integration.integration_pb2.Integration] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["integrations", b"integrations"]) -> None: ...

global___ListIntegrationsResponse = ListIntegrationsResponse

class UpdateIntegrationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTEGRATION_ID_FIELD_NUMBER: builtins.int
    INTEGRATION_SPEC_FIELD_NUMBER: builtins.int
    integration_id: builtins.str
    """Integration Id to update"""
    @property
    def integration_spec(self) -> qwak.integration.integration_pb2.IntegrationSpec:
        """The updated spec"""
    def __init__(
        self,
        *,
        integration_id: builtins.str = ...,
        integration_spec: qwak.integration.integration_pb2.IntegrationSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["integration_spec", b"integration_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["integration_id", b"integration_id", "integration_spec", b"integration_spec"]) -> None: ...

global___UpdateIntegrationRequest = UpdateIntegrationRequest

class UpdateIntegrationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateIntegrationResponse = UpdateIntegrationResponse

class DeleteIntegrationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTEGRATION_ID_FIELD_NUMBER: builtins.int
    integration_id: builtins.str
    """Integration Id to delete"""
    def __init__(
        self,
        *,
        integration_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["integration_id", b"integration_id"]) -> None: ...

global___DeleteIntegrationRequest = DeleteIntegrationRequest

class DeleteIntegrationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteIntegrationResponse = DeleteIntegrationResponse

class ValidateIntegrationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALIDATION_SPEC_FIELD_NUMBER: builtins.int
    @property
    def validation_spec(self) -> qwak.integration.integration_pb2.IntegrationValidationSpec: ...
    def __init__(
        self,
        *,
        validation_spec: qwak.integration.integration_pb2.IntegrationValidationSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["validation_spec", b"validation_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["validation_spec", b"validation_spec"]) -> None: ...

global___ValidateIntegrationRequest = ValidateIntegrationRequest

class ValidateIntegrationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> qwak.integration.integration_pb2.ValidationIntegrationResult:
        """The validation result"""
    def __init__(
        self,
        *,
        result: qwak.integration.integration_pb2.ValidationIntegrationResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["result", b"result"]) -> None: ...

global___ValidateIntegrationResponse = ValidateIntegrationResponse

class GetIntegrationOptionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTEGRATION_ID_FIELD_NUMBER: builtins.int
    integration_id: builtins.str
    """The integration to get options for"""
    def __init__(
        self,
        *,
        integration_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["integration_id", b"integration_id"]) -> None: ...

global___GetIntegrationOptionsRequest = GetIntegrationOptionsRequest

class GetIntegrationOptionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> qwak.integration.integration_pb2.IntegrationOptions:
        """The integration options"""
    def __init__(
        self,
        *,
        options: qwak.integration.integration_pb2.IntegrationOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___GetIntegrationOptionsResponse = GetIntegrationOptionsResponse
