# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/self_service/account/v0/account_status.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1qwak/self_service/account/v0/account_status.proto\x12\x1cqwak.self_service.account.v0\"\xbf\x01\n\rAccountStatus\x12_\n\x1c\x61\x63\x63ount_creation_in_progress\x18\x01 \x01(\x0b\x32\x37.qwak.self_service.account.v0.AccountCreationInProgressH\x00\x12\x43\n\raccount_ready\x18\x02 \x01(\x0b\x32*.qwak.self_service.account.v0.AccountReadyH\x00\x42\x08\n\x06status\"\x1b\n\x19\x41\x63\x63ountCreationInProgress\"\"\n\x0c\x41\x63\x63ountReady\x12\x12\n\naccount_id\x18\x01 \x01(\tB\xb9\x01\n#com.qwak.ai.self_service.account.v0P\x01Z\x8f\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/self_service/account/v0;self_service_account_v0b\x06proto3')



_ACCOUNTSTATUS = DESCRIPTOR.message_types_by_name['AccountStatus']
_ACCOUNTCREATIONINPROGRESS = DESCRIPTOR.message_types_by_name['AccountCreationInProgress']
_ACCOUNTREADY = DESCRIPTOR.message_types_by_name['AccountReady']
AccountStatus = _reflection.GeneratedProtocolMessageType('AccountStatus', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTSTATUS,
  '__module__' : 'qwak.self_service.account.v0.account_status_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.AccountStatus)
  })
_sym_db.RegisterMessage(AccountStatus)

AccountCreationInProgress = _reflection.GeneratedProtocolMessageType('AccountCreationInProgress', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTCREATIONINPROGRESS,
  '__module__' : 'qwak.self_service.account.v0.account_status_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.AccountCreationInProgress)
  })
_sym_db.RegisterMessage(AccountCreationInProgress)

AccountReady = _reflection.GeneratedProtocolMessageType('AccountReady', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTREADY,
  '__module__' : 'qwak.self_service.account.v0.account_status_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.AccountReady)
  })
_sym_db.RegisterMessage(AccountReady)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.qwak.ai.self_service.account.v0P\001Z\217\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/self_service/account/v0;self_service_account_v0'
  _ACCOUNTSTATUS._serialized_start=84
  _ACCOUNTSTATUS._serialized_end=275
  _ACCOUNTCREATIONINPROGRESS._serialized_start=277
  _ACCOUNTCREATIONINPROGRESS._serialized_end=304
  _ACCOUNTREADY._serialized_start=306
  _ACCOUNTREADY._serialized_end=340
# @@protoc_insertion_point(module_scope)
