# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.automation.v1 import automation_management_service_pb2 as qwak_dot_automation_dot_v1_dot_automation__management__service__pb2


class AutomationManagementServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateAutomation = channel.unary_unary(
                '/qwak.automation.v1.AutomationManagementService/CreateAutomation',
                request_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.CreateAutomationRequest.SerializeToString,
                response_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.CreateAutomationResponse.FromString,
                )
        self.UpdateAutomation = channel.unary_unary(
                '/qwak.automation.v1.AutomationManagementService/UpdateAutomation',
                request_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.UpdateAutomationRequest.SerializeToString,
                response_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.UpdateAutomationResponse.FromString,
                )
        self.DeleteAutomation = channel.unary_unary(
                '/qwak.automation.v1.AutomationManagementService/DeleteAutomation',
                request_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.DeleteAutomationRequest.SerializeToString,
                response_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.DeleteAutomationResponse.FromString,
                )
        self.GetAutomation = channel.unary_unary(
                '/qwak.automation.v1.AutomationManagementService/GetAutomation',
                request_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.GetAutomationRequest.SerializeToString,
                response_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.GetAutomationResponse.FromString,
                )
        self.GetAutomationByName = channel.unary_unary(
                '/qwak.automation.v1.AutomationManagementService/GetAutomationByName',
                request_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.GetAutomationByNameRequest.SerializeToString,
                response_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.GetAutomationByNameResponse.FromString,
                )
        self.ListAutomations = channel.unary_unary(
                '/qwak.automation.v1.AutomationManagementService/ListAutomations',
                request_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListAutomationsRequest.SerializeToString,
                response_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListAutomationsResponse.FromString,
                )
        self.ListAutomationExecutions = channel.unary_unary(
                '/qwak.automation.v1.AutomationManagementService/ListAutomationExecutions',
                request_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListAutomationExecutionsRequest.SerializeToString,
                response_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListAutomationExecutionsResponse.FromString,
                )
        self.ListLastAutomationExecutions = channel.unary_unary(
                '/qwak.automation.v1.AutomationManagementService/ListLastAutomationExecutions',
                request_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListLastAutomationExecutionsRequest.SerializeToString,
                response_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListLastAutomationExecutionsResponse.FromString,
                )
        self.RegisterAutomationExecution = channel.unary_unary(
                '/qwak.automation.v1.AutomationManagementService/RegisterAutomationExecution',
                request_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.RegisterAutomationExecutionRequest.SerializeToString,
                response_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.RegisterAutomationExecutionResponse.FromString,
                )
        self.UpdateAutomationExecution = channel.unary_unary(
                '/qwak.automation.v1.AutomationManagementService/UpdateAutomationExecution',
                request_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.UpdateAutomationExecutionRequest.SerializeToString,
                response_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.UpdateAutomationExecutionResponse.FromString,
                )
        self.ToggleAutomationActivity = channel.unary_unary(
                '/qwak.automation.v1.AutomationManagementService/ToggleAutomationActivity',
                request_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ToggleAutomationActivityRequest.SerializeToString,
                response_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ToggleAutomationActivityResponse.FromString,
                )
        self.RunAutomation = channel.unary_unary(
                '/qwak.automation.v1.AutomationManagementService/RunAutomation',
                request_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.RunAutomationRequest.SerializeToString,
                response_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.RunAutomationResponse.FromString,
                )


class AutomationManagementServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateAutomation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAutomation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAutomation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAutomation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAutomationByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAutomations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAutomationExecutions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListLastAutomationExecutions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterAutomationExecution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAutomationExecution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ToggleAutomationActivity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunAutomation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AutomationManagementServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateAutomation': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAutomation,
                    request_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.CreateAutomationRequest.FromString,
                    response_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.CreateAutomationResponse.SerializeToString,
            ),
            'UpdateAutomation': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAutomation,
                    request_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.UpdateAutomationRequest.FromString,
                    response_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.UpdateAutomationResponse.SerializeToString,
            ),
            'DeleteAutomation': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAutomation,
                    request_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.DeleteAutomationRequest.FromString,
                    response_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.DeleteAutomationResponse.SerializeToString,
            ),
            'GetAutomation': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAutomation,
                    request_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.GetAutomationRequest.FromString,
                    response_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.GetAutomationResponse.SerializeToString,
            ),
            'GetAutomationByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAutomationByName,
                    request_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.GetAutomationByNameRequest.FromString,
                    response_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.GetAutomationByNameResponse.SerializeToString,
            ),
            'ListAutomations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAutomations,
                    request_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListAutomationsRequest.FromString,
                    response_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListAutomationsResponse.SerializeToString,
            ),
            'ListAutomationExecutions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAutomationExecutions,
                    request_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListAutomationExecutionsRequest.FromString,
                    response_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListAutomationExecutionsResponse.SerializeToString,
            ),
            'ListLastAutomationExecutions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListLastAutomationExecutions,
                    request_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListLastAutomationExecutionsRequest.FromString,
                    response_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListLastAutomationExecutionsResponse.SerializeToString,
            ),
            'RegisterAutomationExecution': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterAutomationExecution,
                    request_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.RegisterAutomationExecutionRequest.FromString,
                    response_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.RegisterAutomationExecutionResponse.SerializeToString,
            ),
            'UpdateAutomationExecution': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAutomationExecution,
                    request_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.UpdateAutomationExecutionRequest.FromString,
                    response_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.UpdateAutomationExecutionResponse.SerializeToString,
            ),
            'ToggleAutomationActivity': grpc.unary_unary_rpc_method_handler(
                    servicer.ToggleAutomationActivity,
                    request_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ToggleAutomationActivityRequest.FromString,
                    response_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ToggleAutomationActivityResponse.SerializeToString,
            ),
            'RunAutomation': grpc.unary_unary_rpc_method_handler(
                    servicer.RunAutomation,
                    request_deserializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.RunAutomationRequest.FromString,
                    response_serializer=qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.RunAutomationResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.automation.v1.AutomationManagementService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AutomationManagementService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateAutomation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.automation.v1.AutomationManagementService/CreateAutomation',
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.CreateAutomationRequest.SerializeToString,
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.CreateAutomationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAutomation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.automation.v1.AutomationManagementService/UpdateAutomation',
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.UpdateAutomationRequest.SerializeToString,
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.UpdateAutomationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAutomation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.automation.v1.AutomationManagementService/DeleteAutomation',
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.DeleteAutomationRequest.SerializeToString,
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.DeleteAutomationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAutomation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.automation.v1.AutomationManagementService/GetAutomation',
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.GetAutomationRequest.SerializeToString,
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.GetAutomationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAutomationByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.automation.v1.AutomationManagementService/GetAutomationByName',
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.GetAutomationByNameRequest.SerializeToString,
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.GetAutomationByNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAutomations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.automation.v1.AutomationManagementService/ListAutomations',
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListAutomationsRequest.SerializeToString,
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListAutomationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAutomationExecutions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.automation.v1.AutomationManagementService/ListAutomationExecutions',
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListAutomationExecutionsRequest.SerializeToString,
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListAutomationExecutionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListLastAutomationExecutions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.automation.v1.AutomationManagementService/ListLastAutomationExecutions',
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListLastAutomationExecutionsRequest.SerializeToString,
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ListLastAutomationExecutionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterAutomationExecution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.automation.v1.AutomationManagementService/RegisterAutomationExecution',
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.RegisterAutomationExecutionRequest.SerializeToString,
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.RegisterAutomationExecutionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAutomationExecution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.automation.v1.AutomationManagementService/UpdateAutomationExecution',
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.UpdateAutomationExecutionRequest.SerializeToString,
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.UpdateAutomationExecutionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ToggleAutomationActivity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.automation.v1.AutomationManagementService/ToggleAutomationActivity',
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ToggleAutomationActivityRequest.SerializeToString,
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.ToggleAutomationActivityResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunAutomation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.automation.v1.AutomationManagementService/RunAutomation',
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.RunAutomationRequest.SerializeToString,
            qwak_dot_automation_dot_v1_dot_automation__management__service__pb2.RunAutomationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
