# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/account/v1/jfrog_tenant_details.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9qwak/administration/account/v1/jfrog_tenant_details.proto\x12\x1eqwak.administration.account.v1\"\x83\x01\n\x12JfrogTenantDetails\x12\x11\n\ttenant_id\x18\x01 \x01(\t\x12Z\n\x1d\x64\x65\x66\x61ult_jfrog_project_details\x18\x02 \x01(\x0b\x32\x33.qwak.administration.account.v1.JfrogProjectDetails\"*\n\x13JfrogProjectDetails\x12\x13\n\x0bproject_key\x18\x01 \x01(\t\"t\n\x0fJfrogTenantSpec\x12\x11\n\ttenant_id\x18\x01 \x01(\t\x12N\n\x14\x64\x65\x66\x61ult_project_spec\x18\x02 \x01(\x0b\x32\x30.qwak.administration.account.v1.JfrogProjectSpec\"\'\n\x10JfrogProjectSpec\x12\x13\n\x0bproject_key\x18\x01 \x01(\tB\xb4\x01\n)com.qwak.ai.administration.api.account.v1P\x01Z\x84\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/account/v1;account_v0b\x06proto3')



_JFROGTENANTDETAILS = DESCRIPTOR.message_types_by_name['JfrogTenantDetails']
_JFROGPROJECTDETAILS = DESCRIPTOR.message_types_by_name['JfrogProjectDetails']
_JFROGTENANTSPEC = DESCRIPTOR.message_types_by_name['JfrogTenantSpec']
_JFROGPROJECTSPEC = DESCRIPTOR.message_types_by_name['JfrogProjectSpec']
JfrogTenantDetails = _reflection.GeneratedProtocolMessageType('JfrogTenantDetails', (_message.Message,), {
  'DESCRIPTOR' : _JFROGTENANTDETAILS,
  '__module__' : 'qwak.administration.account.v1.jfrog_tenant_details_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.JfrogTenantDetails)
  })
_sym_db.RegisterMessage(JfrogTenantDetails)

JfrogProjectDetails = _reflection.GeneratedProtocolMessageType('JfrogProjectDetails', (_message.Message,), {
  'DESCRIPTOR' : _JFROGPROJECTDETAILS,
  '__module__' : 'qwak.administration.account.v1.jfrog_tenant_details_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.JfrogProjectDetails)
  })
_sym_db.RegisterMessage(JfrogProjectDetails)

JfrogTenantSpec = _reflection.GeneratedProtocolMessageType('JfrogTenantSpec', (_message.Message,), {
  'DESCRIPTOR' : _JFROGTENANTSPEC,
  '__module__' : 'qwak.administration.account.v1.jfrog_tenant_details_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.JfrogTenantSpec)
  })
_sym_db.RegisterMessage(JfrogTenantSpec)

JfrogProjectSpec = _reflection.GeneratedProtocolMessageType('JfrogProjectSpec', (_message.Message,), {
  'DESCRIPTOR' : _JFROGPROJECTSPEC,
  '__module__' : 'qwak.administration.account.v1.jfrog_tenant_details_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.JfrogProjectSpec)
  })
_sym_db.RegisterMessage(JfrogProjectSpec)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.qwak.ai.administration.api.account.v1P\001Z\204\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/account/v1;account_v0'
  _JFROGTENANTDETAILS._serialized_start=94
  _JFROGTENANTDETAILS._serialized_end=225
  _JFROGPROJECTDETAILS._serialized_start=227
  _JFROGPROJECTDETAILS._serialized_end=269
  _JFROGTENANTSPEC._serialized_start=271
  _JFROGTENANTSPEC._serialized_end=387
  _JFROGPROJECTSPEC._serialized_start=389
  _JFROGPROJECTSPEC._serialized_end=428
# @@protoc_insertion_point(module_scope)
