# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.feature_store.jobs.v1 import job_service_pb2 as qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2


class JobServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ApplyJob = channel.unary_unary(
                '/qwak.feature.store.jobs.v1.JobService/ApplyJob',
                request_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.ApplyJobRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.ApplyJobResponse.FromString,
                )
        self.InitPagination = channel.unary_unary(
                '/qwak.feature.store.jobs.v1.JobService/InitPagination',
                request_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.InitPaginationRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.InitPaginationResponse.FromString,
                )
        self.ListJobs = channel.unary_unary(
                '/qwak.feature.store.jobs.v1.JobService/ListJobs',
                request_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.ListJobsRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.ListJobsResponse.FromString,
                )
        self.GetLatestSuccessfulJob = channel.unary_unary(
                '/qwak.feature.store.jobs.v1.JobService/GetLatestSuccessfulJob',
                request_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetLatestSuccessfulJobRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetLatestSuccessfulJobResponse.FromString,
                )
        self.GetAllLatestSuccessfulJobs = channel.unary_unary(
                '/qwak.feature.store.jobs.v1.JobService/GetAllLatestSuccessfulJobs',
                request_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetAllLatestSuccessfulJobsRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetAllLatestSuccessfulJobsResponse.FromString,
                )
        self.GetLatestJob = channel.unary_unary(
                '/qwak.feature.store.jobs.v1.JobService/GetLatestJob',
                request_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetLatestJobRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetLatestJobResponse.FromString,
                )
        self.DeleteFeaturesetJobs = channel.unary_unary(
                '/qwak.feature.store.jobs.v1.JobService/DeleteFeaturesetJobs',
                request_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.DeleteFeaturesetJobsRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.DeleteFeaturesetJobsResponse.FromString,
                )
        self.DeleteFeaturesetJobByJobId = channel.unary_unary(
                '/qwak.feature.store.jobs.v1.JobService/DeleteFeaturesetJobByJobId',
                request_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.DeleteFeaturesetJobByJobIdRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.DeleteFeaturesetJobByJobIdResponse.FromString,
                )
        self.GetJobsSummaries = channel.unary_unary(
                '/qwak.feature.store.jobs.v1.JobService/GetJobsSummaries',
                request_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetJobsSummariesRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetJobsSummariesResponse.FromString,
                )


class JobServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ApplyJob(self, request, context):
        """Upsert a job record
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InitPagination(self, request, context):
        """Initialise a pagination 'session' - returns the amount of records, and first record running id delimiter
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListJobs(self, request, context):
        """List all job records of a featureset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLatestSuccessfulJob(self, request, context):
        """Get latest successful job of a featureset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllLatestSuccessfulJobs(self, request, context):
        """Get all latest successful jobs for each featureset in the environment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLatestJob(self, request, context):
        """Get latest job of a featureset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFeaturesetJobs(self, request, context):
        """Delete all featureset jobs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFeaturesetJobByJobId(self, request, context):
        """Delete featureset job by job id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetJobsSummaries(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_JobServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ApplyJob': grpc.unary_unary_rpc_method_handler(
                    servicer.ApplyJob,
                    request_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.ApplyJobRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.ApplyJobResponse.SerializeToString,
            ),
            'InitPagination': grpc.unary_unary_rpc_method_handler(
                    servicer.InitPagination,
                    request_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.InitPaginationRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.InitPaginationResponse.SerializeToString,
            ),
            'ListJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListJobs,
                    request_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.ListJobsRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.ListJobsResponse.SerializeToString,
            ),
            'GetLatestSuccessfulJob': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLatestSuccessfulJob,
                    request_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetLatestSuccessfulJobRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetLatestSuccessfulJobResponse.SerializeToString,
            ),
            'GetAllLatestSuccessfulJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllLatestSuccessfulJobs,
                    request_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetAllLatestSuccessfulJobsRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetAllLatestSuccessfulJobsResponse.SerializeToString,
            ),
            'GetLatestJob': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLatestJob,
                    request_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetLatestJobRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetLatestJobResponse.SerializeToString,
            ),
            'DeleteFeaturesetJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFeaturesetJobs,
                    request_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.DeleteFeaturesetJobsRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.DeleteFeaturesetJobsResponse.SerializeToString,
            ),
            'DeleteFeaturesetJobByJobId': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFeaturesetJobByJobId,
                    request_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.DeleteFeaturesetJobByJobIdRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.DeleteFeaturesetJobByJobIdResponse.SerializeToString,
            ),
            'GetJobsSummaries': grpc.unary_unary_rpc_method_handler(
                    servicer.GetJobsSummaries,
                    request_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetJobsSummariesRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetJobsSummariesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.feature.store.jobs.v1.JobService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class JobService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ApplyJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.jobs.v1.JobService/ApplyJob',
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.ApplyJobRequest.SerializeToString,
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.ApplyJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InitPagination(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.jobs.v1.JobService/InitPagination',
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.InitPaginationRequest.SerializeToString,
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.InitPaginationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.jobs.v1.JobService/ListJobs',
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.ListJobsRequest.SerializeToString,
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.ListJobsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLatestSuccessfulJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.jobs.v1.JobService/GetLatestSuccessfulJob',
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetLatestSuccessfulJobRequest.SerializeToString,
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetLatestSuccessfulJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAllLatestSuccessfulJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.jobs.v1.JobService/GetAllLatestSuccessfulJobs',
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetAllLatestSuccessfulJobsRequest.SerializeToString,
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetAllLatestSuccessfulJobsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLatestJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.jobs.v1.JobService/GetLatestJob',
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetLatestJobRequest.SerializeToString,
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetLatestJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFeaturesetJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.jobs.v1.JobService/DeleteFeaturesetJobs',
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.DeleteFeaturesetJobsRequest.SerializeToString,
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.DeleteFeaturesetJobsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFeaturesetJobByJobId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.jobs.v1.JobService/DeleteFeaturesetJobByJobId',
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.DeleteFeaturesetJobByJobIdRequest.SerializeToString,
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.DeleteFeaturesetJobByJobIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetJobsSummaries(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.jobs.v1.JobService/GetJobsSummaries',
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetJobsSummariesRequest.SerializeToString,
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetJobsSummariesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
