# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/authenticated_user/v1/credentials.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;qwak/administration/authenticated_user/v1/credentials.proto\x12)qwak.administration.authenticated_user.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8a\x01\n\x10\x43loudCredentials\x12g\n\x19\x61ws_temporary_credentials\x18\x01 \x01(\x0b\x32\x42.qwak.administration.authenticated_user.v1.AwsTemporaryCredentialsH\x00\x42\r\n\x0b\x63redentials\"\x97\x01\n\x17\x41wsTemporaryCredentials\x12\x15\n\raccess_key_id\x18\x01 \x01(\t\x12\x19\n\x11secret_access_key\x18\x02 \x01(\t\x12\x15\n\rsession_token\x18\x03 \x01(\t\x12\x33\n\x0f\x65xpiration_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampBN\n4com.qwak.ai.administration.api.authenticated_user.v1P\x01Z\x14.;authenticated_userb\x06proto3')



_CLOUDCREDENTIALS = DESCRIPTOR.message_types_by_name['CloudCredentials']
_AWSTEMPORARYCREDENTIALS = DESCRIPTOR.message_types_by_name['AwsTemporaryCredentials']
CloudCredentials = _reflection.GeneratedProtocolMessageType('CloudCredentials', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDCREDENTIALS,
  '__module__' : 'qwak.administration.authenticated_user.v1.credentials_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authenticated_user.v1.CloudCredentials)
  })
_sym_db.RegisterMessage(CloudCredentials)

AwsTemporaryCredentials = _reflection.GeneratedProtocolMessageType('AwsTemporaryCredentials', (_message.Message,), {
  'DESCRIPTOR' : _AWSTEMPORARYCREDENTIALS,
  '__module__' : 'qwak.administration.authenticated_user.v1.credentials_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authenticated_user.v1.AwsTemporaryCredentials)
  })
_sym_db.RegisterMessage(AwsTemporaryCredentials)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n4com.qwak.ai.administration.api.authenticated_user.v1P\001Z\024.;authenticated_user'
  _CLOUDCREDENTIALS._serialized_start=140
  _CLOUDCREDENTIALS._serialized_end=278
  _AWSTEMPORARYCREDENTIALS._serialized_start=281
  _AWSTEMPORARYCREDENTIALS._serialized_end=432
# @@protoc_insertion_point(module_scope)
