def real_time_client():
    """
    This is a placeholder for a real time client mock. It is used to test the real time client during the build process.
    During the build process a fixture with this name will be available for testing purposes against the created model.
    :return: RealTimeClient
    """
    pass
