# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/v0/authentication/authentication_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBqwak/administration/v0/authentication/authentication_service.proto\x12\"qwak.administration.authentication\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe3\x01\n\x13\x41uthenticateRequest\x12^\n\x18username_password_method\x18\x01 \x01(\x0b\x32:.qwak.administration.authentication.UsernamePasswordMethodH\x00\x12S\n\x13qwak_api_key_method\x18\x02 \x01(\x0b\x32\x34.qwak.administration.authentication.QwakApiKeyMethodH\x00\x42\x17\n\x15\x61uthentication_method\"<\n\x16UsernamePasswordMethod\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"(\n\x10QwakApiKeyMethod\x12\x14\n\x0cqwak_api_key\x18\x01 \x01(\t\"\\\n\x14\x41uthenticateResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12.\n\nexpired_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp2\x9b\x01\n\x15\x41uthenticationService\x12\x81\x01\n\x0c\x41uthenticate\x12\x37.qwak.administration.authentication.AuthenticateRequest\x1a\x38.qwak.administration.authentication.AuthenticateResponseB\xb7\x01\n\x1e\x63om.qwak.ai.administration.apiP\x01Z\x92\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/v0/authentication;authentication_v0b\x06proto3')



_AUTHENTICATEREQUEST = DESCRIPTOR.message_types_by_name['AuthenticateRequest']
_USERNAMEPASSWORDMETHOD = DESCRIPTOR.message_types_by_name['UsernamePasswordMethod']
_QWAKAPIKEYMETHOD = DESCRIPTOR.message_types_by_name['QwakApiKeyMethod']
_AUTHENTICATERESPONSE = DESCRIPTOR.message_types_by_name['AuthenticateResponse']
AuthenticateRequest = _reflection.GeneratedProtocolMessageType('AuthenticateRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATEREQUEST,
  '__module__' : 'qwak.administration.v0.authentication.authentication_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authentication.AuthenticateRequest)
  })
_sym_db.RegisterMessage(AuthenticateRequest)

UsernamePasswordMethod = _reflection.GeneratedProtocolMessageType('UsernamePasswordMethod', (_message.Message,), {
  'DESCRIPTOR' : _USERNAMEPASSWORDMETHOD,
  '__module__' : 'qwak.administration.v0.authentication.authentication_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authentication.UsernamePasswordMethod)
  })
_sym_db.RegisterMessage(UsernamePasswordMethod)

QwakApiKeyMethod = _reflection.GeneratedProtocolMessageType('QwakApiKeyMethod', (_message.Message,), {
  'DESCRIPTOR' : _QWAKAPIKEYMETHOD,
  '__module__' : 'qwak.administration.v0.authentication.authentication_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authentication.QwakApiKeyMethod)
  })
_sym_db.RegisterMessage(QwakApiKeyMethod)

AuthenticateResponse = _reflection.GeneratedProtocolMessageType('AuthenticateResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATERESPONSE,
  '__module__' : 'qwak.administration.v0.authentication.authentication_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authentication.AuthenticateResponse)
  })
_sym_db.RegisterMessage(AuthenticateResponse)

_AUTHENTICATIONSERVICE = DESCRIPTOR.services_by_name['AuthenticationService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.qwak.ai.administration.apiP\001Z\222\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/v0/authentication;authentication_v0'
  _AUTHENTICATEREQUEST._serialized_start=140
  _AUTHENTICATEREQUEST._serialized_end=367
  _USERNAMEPASSWORDMETHOD._serialized_start=369
  _USERNAMEPASSWORDMETHOD._serialized_end=429
  _QWAKAPIKEYMETHOD._serialized_start=431
  _QWAKAPIKEYMETHOD._serialized_end=471
  _AUTHENTICATERESPONSE._serialized_start=473
  _AUTHENTICATERESPONSE._serialized_end=565
  _AUTHENTICATIONSERVICE._serialized_start=568
  _AUTHENTICATIONSERVICE._serialized_end=723
# @@protoc_insertion_point(module_scope)
