"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.self_service.account.v0.account_status_pb2
import qwak.self_service.account.v0.managing_account_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CreateAccountCreationRequestRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> qwak.self_service.account.v0.managing_account_pb2.CreateAccountOptions:
        """Options for creating account"""
    def __init__(
        self,
        *,
        options: qwak.self_service.account.v0.managing_account_pb2.CreateAccountOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___CreateAccountCreationRequestRequest = CreateAccountCreationRequestRequest

class CreateAccountCreationRequestResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    @property
    def description(self) -> qwak.self_service.account.v0.managing_account_pb2.CreateAccountRequestDescription: ...
    def __init__(
        self,
        *,
        description: qwak.self_service.account.v0.managing_account_pb2.CreateAccountRequestDescription | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["description", b"description"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description"]) -> None: ...

global___CreateAccountCreationRequestResponse = CreateAccountCreationRequestResponse

class ValidateAccountCreationRequestRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> qwak.self_service.account.v0.managing_account_pb2.CreateAccountOptions:
        """Options for creating account"""
    def __init__(
        self,
        *,
        options: qwak.self_service.account.v0.managing_account_pb2.CreateAccountOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___ValidateAccountCreationRequestRequest = ValidateAccountCreationRequestRequest

class ValidateAccountCreationRequestResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ERROR_DESCRIPTION_FIELD_NUMBER: builtins.int
    @property
    def error_description(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The error description"""
    def __init__(
        self,
        *,
        error_description: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["error_description", b"error_description"]) -> None: ...

global___ValidateAccountCreationRequestResponse = ValidateAccountCreationRequestResponse

class GetAccountStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetAccountStatusRequest = GetAccountStatusRequest

class GetAccountStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    @property
    def status(self) -> qwak.self_service.account.v0.account_status_pb2.AccountStatus:
        """The account status"""
    def __init__(
        self,
        *,
        status: qwak.self_service.account.v0.account_status_pb2.AccountStatus | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status"]) -> None: ...

global___GetAccountStatusResponse = GetAccountStatusResponse

class GetCloudProviderSupportedRegionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetCloudProviderSupportedRegionsRequest = GetCloudProviderSupportedRegionsRequest

class GetCloudProviderSupportedRegionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUPPORTED_REGIONS_FIELD_NUMBER: builtins.int
    @property
    def supported_regions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.self_service.account.v0.managing_account_pb2.CloudProviderRegions]:
        """The supported regions"""
    def __init__(
        self,
        *,
        supported_regions: collections.abc.Iterable[qwak.self_service.account.v0.managing_account_pb2.CloudProviderRegions] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["supported_regions", b"supported_regions"]) -> None: ...

global___GetCloudProviderSupportedRegionsResponse = GetCloudProviderSupportedRegionsResponse
