"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AccountStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_CREATION_IN_PROGRESS_FIELD_NUMBER: builtins.int
    ACCOUNT_READY_FIELD_NUMBER: builtins.int
    @property
    def account_creation_in_progress(self) -> global___AccountCreationInProgress: ...
    @property
    def account_ready(self) -> global___AccountReady: ...
    def __init__(
        self,
        *,
        account_creation_in_progress: global___AccountCreationInProgress | None = ...,
        account_ready: global___AccountReady | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["account_creation_in_progress", b"account_creation_in_progress", "account_ready", b"account_ready", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_creation_in_progress", b"account_creation_in_progress", "account_ready", b"account_ready", "status", b"status"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["status", b"status"]) -> typing_extensions.Literal["account_creation_in_progress", "account_ready"] | None: ...

global___AccountStatus = AccountStatus

class AccountCreationInProgress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___AccountCreationInProgress = AccountCreationInProgress

class AccountReady(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    account_id: builtins.str
    """The account id"""
    def __init__(
        self,
        *,
        account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id"]) -> None: ...

global___AccountReady = AccountReady
