# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/logging/log_line.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bqwak/logging/log_line.proto\x12\x14qwak.logging.service\"\xc3\x01\n\x07LogLine\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x1a\n\x12source_instance_id\x18\x02 \x01(\t\x12\x1e\n\x16ingested_iso_timestamp\x18\x03 \x01(\t\x12=\n\x08metadata\x18\x04 \x03(\x0b\x32+.qwak.logging.service.LogLine.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\"\n\x1e\x63om.qwak.ai.logging.reader.apiP\x01\x62\x06proto3')



_LOGLINE = DESCRIPTOR.message_types_by_name['LogLine']
_LOGLINE_METADATAENTRY = _LOGLINE.nested_types_by_name['MetadataEntry']
LogLine = _reflection.GeneratedProtocolMessageType('LogLine', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _LOGLINE_METADATAENTRY,
    '__module__' : 'qwak.logging.log_line_pb2'
    # @@protoc_insertion_point(class_scope:qwak.logging.service.LogLine.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _LOGLINE,
  '__module__' : 'qwak.logging.log_line_pb2'
  # @@protoc_insertion_point(class_scope:qwak.logging.service.LogLine)
  })
_sym_db.RegisterMessage(LogLine)
_sym_db.RegisterMessage(LogLine.MetadataEntry)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.qwak.ai.logging.reader.apiP\001'
  _LOGLINE_METADATAENTRY._options = None
  _LOGLINE_METADATAENTRY._serialized_options = b'8\001'
  _LOGLINE._serialized_start=54
  _LOGLINE._serialized_end=249
  _LOGLINE_METADATAENTRY._serialized_start=202
  _LOGLINE_METADATAENTRY._serialized_end=249
# @@protoc_insertion_point(module_scope)
